/**
 * Required External Modules and Interfaces
 */
import express, {Request, Response} from 'express';
import {Guid} from 'guid-typescript';
import logger from '../../../middleware/logger';
import {ClimbingGym} from './ClimbingGym.interface';
import * as GymService from './climbingGyms.service';
import {verifyCaptcha} from '../common/VerifyCaptcha';

/**
 * Router Definition
 */
export const climbingGymRouter = express.Router();

climbingGymRouter.get('/', async (req: Request, res: Response) => {
    try {
        const gyms: ClimbingGym[] = await GymService.findAll();

        res.status(200).send(gyms);
    } catch (e) {
        let errorGuid = Guid.create().toString();
        logger.error('Error handling a request: ' + e.message, {reference: errorGuid});
        res.status(500).send({
            'status': 'PROCESSING_ERROR',
            'message': 'Internal Server Error. Try again later.',
            'reference': errorGuid
        });
    }
});

climbingGymRouter.post('/', async (req: Request, res: Response) => {
    try {
        let name = req.query.name as string;
        let city = req.query.city as string;
        let captcha_token = req.query['h-captcha-response'] as string;

        if (!name || !city || !captcha_token) {
            res.status(400).send({'message': 'Missing parameters'});
            return;
        }

        // Verify captcha
        if (!await verifyCaptcha(captcha_token)) {
            res.status(403).send({'message': 'Invalid Captcha. Please try again.'});
            return;
        }

        let result = await GymService.createGym(name, city);

        if (result) {
            res.status(201).send({'gym_id': result});
        } else {
            res.status(500).send({});
        }
    } catch (e) {
        let errorGuid = Guid.create().toString();
        logger.error('Error handling a request: ' + e.message, {reference: errorGuid});
        res.status(500).send({
            'status': 'PROCESSING_ERROR',
            'message': 'Internal Server Error. Try again later.',
            'reference': errorGuid
        });
    }
});
